==> tencentcloud-sdk-java-3.1.607-sources.jar: com/tencentcloudapi/dasb/v20191018/DasbErrorCode.java <==
package com.tencentcloudapi.dasb.v20191018;
public enum DasbErrorCode {
    // CAM签名/鉴权错误。
     AUTHFAILURE("AuthFailure"),
     
    // 操作失败。
     FAILEDOPERATION("FailedOperation"),
     
    // 目标数据不存在。
     FAILEDOPERATION_DATANOTFOUND("FailedOperation.DataNotFound"),
     
    // 重复数据。
     FAILEDOPERATION_DUPLICATEDATA("FailedOperation.DuplicateData"),
     
    // 内部错误。
     INTERNALERROR("InternalError"),
     
    // 参数错误。
     INVALIDPARAMETER("InvalidParameter"),
     
    // 无效的资源ID，用于资源不存在或已过期。
     INVALIDPARAMETER_RESOURCEID("InvalidParameter.ResourceId"),
     
    // 参数取值错误。
     INVALIDPARAMETERVALUE("InvalidParameterValue"),
     
    // 超过配额限制。
     LIMITEXCEEDED("LimitExceeded"),
     
    // 缺少参数错误。
     MISSINGPARAMETER("MissingParameter"),
     
    // 操作被拒绝。
     OPERATIONDENIED("OperationDenied"),
     
    // 请求的次数超过了频率限制。
     REQUESTLIMITEXCEEDED("RequestLimitExceeded"),
     
    // 资源被占用。
     RESOURCEINUSE("ResourceInUse"),
     
    // 资源不足。
     RESOURCEINSUFFICIENT("ResourceInsufficient"),
     
    // 资源不存在。
     RESOURCENOTFOUND("ResourceNotFound"),
     
    // 资源不可用。
     RESOURCEUNAVAILABLE("ResourceUnavailable"),
     
    // 资源售罄。
     RESOURCESSOLDOUT("ResourcesSoldOut"),
     
    // 未授权操作。
     UNAUTHORIZEDOPERATION("UnauthorizedOperation"),
     
    // 无操作权限。
     UNAUTHORIZEDOPERATION_NOPERMISSION("UnauthorizedOperation.NoPermission"),
     
    // 未知参数错误。
     UNKNOWNPARAMETER("UnknownParameter"),
     
    // 操作不支持。
     UNSUPPORTEDOPERATION("UnsupportedOperation");
     
    private String value;
    private DasbErrorCode (String value){
        this.value = value;
    }
    /**
     * @return errorcode value
     */
    public String getValue() {
        return value;
    }
}

==> tencentcloud-sdk-java-3.1.930-sources.jar: com/tencentcloudapi/dasb/v20191018/DasbErrorCode.java <==
package com.tencentcloudapi.dasb.v20191018;
public enum DasbErrorCode {
    // CAM签名/鉴权错误。
     AUTHFAILURE("AuthFailure"),
     
    // 操作失败。
     FAILEDOPERATION("FailedOperation"),
     
    // 账号或密码错误。
     FAILEDOPERATION_AUTHFAILED("FailedOperation.AuthFailed"),
     
    // 连接服务器失败。
     FAILEDOPERATION_CONNECTIONFAILED("FailedOperation.ConnectionFailed"),
     
    // 目标数据不存在。
     FAILEDOPERATION_DATANOTFOUND("FailedOperation.DataNotFound"),
     
    // 重复数据。
     FAILEDOPERATION_DUPLICATEDATA("FailedOperation.DuplicateData"),
     
    // 操作过于频繁，请稍后再试。
     FAILEDOPERATION_TOOFREQUENT("FailedOperation.TooFrequent"),
     
    // 该VPC已开通服务，请选择其他VPC。
     FAILEDOPERATION_VPCDEPLOYED("FailedOperation.VPCDeployed"),
     
    // 内部错误。
     INTERNALERROR("InternalError"),
     
    // 参数错误。
     INVALIDPARAMETER("InvalidParameter"),
     
    // 无效的资源ID，用于资源不存在或已过期。
     INVALIDPARAMETER_RESOURCEID("InvalidParameter.ResourceId"),
     
    // 参数取值错误。
     INVALIDPARAMETERVALUE("InvalidParameterValue"),
     
    // 超过配额限制。
     LIMITEXCEEDED("LimitExceeded"),
     
    // 缺少参数错误。
     MISSINGPARAMETER("MissingParameter"),
     
    // 操作被拒绝。
     OPERATIONDENIED("OperationDenied"),
     
    // 请求的次数超过了频率限制。
     REQUESTLIMITEXCEEDED("RequestLimitExceeded"),
     
    // 资源被占用。
     RESOURCEINUSE("ResourceInUse"),
     
    // 资源不足。
     RESOURCEINSUFFICIENT("ResourceInsufficient"),
     
    // 资源不存在。
     RESOURCENOTFOUND("ResourceNotFound"),
     
    // 资源不可用。
     RESOURCEUNAVAILABLE("ResourceUnavailable"),
     
    // 资源售罄。
     RESOURCESSOLDOUT("ResourcesSoldOut"),
     
    // 未授权操作。
     UNAUTHORIZEDOPERATION("UnauthorizedOperation"),
     
    // 无操作权限。
     UNAUTHORIZEDOPERATION_NOPERMISSION("UnauthorizedOperation.NoPermission"),
     
    // 未知参数错误。
     UNKNOWNPARAMETER("UnknownParameter"),
     
    // 操作不支持。
     UNSUPPORTEDOPERATION("UnsupportedOperation");
     
    private String value;
    private DasbErrorCode (String value){
        this.value = value;
    }
    /**
     * @return errorcode value
     */
    public String getValue() {
        return value;
    }
}
